@@ -13,7 +13,7 @@ elif sys.platform.startswith("win"):
     NOSIGNAL = 0
 
 
-class NetworkClient(object):
+class NetworkClient:
     '''
     A class for interfacing with the OpenRGB SDK
     '''
@@ -32,9 +32,6 @@ class NetworkClient(object):
         self.port = port
         self.name = name
         self.start_connection()
-        # Requesting the number of devices
-        self.send_header(0, utils.PacketType.NET_PACKET_ID_REQUEST_CONTROLLER_COUNT, 0)
-        self.read()
 
     def start_connection(self):
         '''
@@ -56,7 +53,7 @@ class NetworkClient(object):
 
         # Sending the client name
         name = bytes(f"{self.name}\0", 'utf-8')
-        self.send_header(0, utils.PacketType.NET_PACKET_ID_SET_CLIENT_NAME, len(name))
+        self.send_header(0, utils.PacketType.SET_CLIENT_NAME, len(name))
         self.send_data(name)
 
     def stop_connection(self):
@@ -78,7 +75,7 @@ class NetworkClient(object):
         header = bytearray(utils.HEADER_SIZE)
         try:
             self.sock.recv_into(header)
-        except (ConnectionResetError, BrokenPipeError) as e:
+        except utils.CONNECTION_ERRORS as e:
             self.stop_connection()
             raise utils.OpenRGBDisconnected() from e
 
@@ -91,18 +88,18 @@ class NetworkClient(object):
         if buff[:4] == [b'O', b'R', b'G', b'B']:
             device_id, packet_type, packet_size = buff[4:]
             # print(device_id, packet_type, packet_size)
-            if packet_type == utils.PacketType.NET_PACKET_ID_REQUEST_CONTROLLER_COUNT:
+            if packet_type == utils.PacketType.REQUEST_CONTROLLER_COUNT:
                 try:
                     buff = struct.unpack("I", self.sock.recv(packet_size))
                     self.callback(device_id, packet_type, buff[0])
-                except (ConnectionResetError, BrokenPipeError) as e:
+                except utils.CONNECTION_ERRORS as e:
                     self.stop_connection()
                     raise utils.OpenRGBDisconnected() from e
-            elif packet_type == utils.PacketType.NET_PACKET_ID_REQUEST_CONTROLLER_DATA:
+            elif packet_type == utils.PacketType.REQUEST_CONTROLLER_DATA:
                 data = bytearray(packet_size)
                 try:
                     self.sock.recv_into(data)
-                except (ConnectionResetError, BrokenPipeError) as e:
+                except utils.CONNECTION_ERRORS as e:
                     self.stop_connection()
                     raise utils.OpenRGBDisconnected() from e
                 self.callback(device_id, packet_type, utils.ControllerData.unpack(data))
@@ -115,7 +112,14 @@ class NetworkClient(object):
         '''
         if self.sock is None:
             raise utils.OpenRGBDisconnected()
-        self.send_header(device, utils.PacketType.NET_PACKET_ID_REQUEST_CONTROLLER_DATA, 0)
+        self.send_header(device, utils.PacketType.REQUEST_CONTROLLER_DATA, 0)
+        self.read()
+
+    def requestDeviceNum(self):
+        '''
+        Requesting the number of devices from the SDK server
+        '''
+        self.send_header(0, utils.PacketType.REQUEST_CONTROLLER_COUNT, 0)
         self.read()
 
     def send_header(self, device_id: int, packet_type: int, packet_size: int):
@@ -124,7 +128,7 @@ class NetworkClient(object):
 
         :param device_id: The id of the device to send a header for
         :param packet_type: A utils.PacketType
-        :param packet_size: The full size of the data to be send after the header
+        :param packet_size: The full size of the data to be sent after the header
         '''
         if self.sock is None:
             raise utils.OpenRGBDisconnected()
@@ -132,7 +136,7 @@ class NetworkClient(object):
             self.lock.acquire()
         try:
             self.sock.send(struct.pack('ccccIII', b'O', b'R', b'G', b'B', device_id, packet_type, packet_size), NOSIGNAL)
-        except (ConnectionResetError, BrokenPipeError) as e:
+        except utils.CONNECTION_ERRORS as e:
             self.stop_connection()
             raise utils.OpenRGBDisconnected() from e
 
@@ -146,7 +150,7 @@ class NetworkClient(object):
             raise utils.OpenRGBDisconnected()
         try:
             self.sock.send(data, NOSIGNAL)
-        except (ConnectionResetError, BrokenPipeError) as e:
+        except utils.CONNECTION_ERRORS as e:
             self.stop_connection()
             raise utils.OpenRGBDisconnected() from e
         finally:
